package com.hw.dms.mapper;

import java.util.List;

import com.hw.dms.domain.DmsBillsLubeDetail;
import com.hw.dms.domain.DmsBillsLubeInstance;

/**
 * 润滑工单Mapper接口
 *
 * @author Open Platform
 * @date 2024-02-26
 */
public interface DmsBillsLubeInstanceMapper
{
    /**
     * 查询润滑工单
     *
     * @param lubeInstanceId 润滑工单主键
     * @return 润滑工单
     */
    public DmsBillsLubeInstance selectDmsBillsLubeInstanceByLubeInstanceId(Long lubeInstanceId);

    /**
     * 查询润滑工单列表
     *
     * @param dmsBillsLubeInstance 润滑工单
     * @return 润滑工单集合
     */
    public List<DmsBillsLubeInstance> selectDmsBillsLubeInstanceList(DmsBillsLubeInstance dmsBillsLubeInstance);

    /**
     * 新增润滑工单
     *
     * @param dmsBillsLubeInstance 润滑工单
     * @return 结果
     */
    public int insertDmsBillsLubeInstance(DmsBillsLubeInstance dmsBillsLubeInstance);

    /**
     * 修改润滑工单
     *
     * @param dmsBillsLubeInstance 润滑工单
     * @return 结果
     */
    public int updateDmsBillsLubeInstance(DmsBillsLubeInstance dmsBillsLubeInstance);

    /**
     * 删除润滑工单
     *
     * @param lubeInstanceId 润滑工单主键
     * @return 结果
     */
    public int deleteDmsBillsLubeInstanceByLubeInstanceId(Long lubeInstanceId);

    /**
     * 批量删除润滑工单
     *
     * @param lubeInstanceIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBillsLubeInstanceByLubeInstanceIds(Long[] lubeInstanceIds);




    /**
     * 批量新增润滑工单明细
     *
     * @param dmsBillsLubeDetailList 润滑工单明细列表
     * @return 结果
     */
    public int batchDmsBillsLubeDetail(List<DmsBillsLubeDetail> dmsBillsLubeDetailList);

    /**
     * 查询最新一条润滑工单,Join 第一步实例节点
     *
     * @param dmsBillsLubeInstance 润滑工单
     * @return 润滑工单
     */
    public DmsBillsLubeInstance selectNewestDmsBillsLubeInstance(DmsBillsLubeInstance dmsBillsLubeInstance);

}
